@@ -21,6 +21,15 @@ class MonitoringApi:
             elif p["name"] == "influx_analytics":
                 self._proxy_influx_analytics = p["id"]
 
+    def authorize(self, org_id: str):
+        path = "/accounts/api/authorize"
+        data = {
+            "namespace": "monitoringcenter",
+            "action": "GET",
+            "resources": [f"/organizations/{org_id}/admin", f"/organizations/{org_id}/viewer"]
+        }
+        return self._client.request(path, method="POST", body=data)
+
     def boot_data(self):
         path = "/monitoring/api/visualizer/api/bootdata"
         data = self._client.request(path)
@@ -29,6 +38,11 @@ class MonitoringApi:
             self._influx_db = influx_data["database"]
             self._proxy_influx_db = influx_data["id"]
 
+    def get_applications(self, environment_id: str):
+        # /monitoring/api/visualizer/environments/c22c6dfd-0257-42a5-b64e-6037910935e8/applications
+        path = f"/monitoring/api/visualizer/environments/{environment_id}/applications"
+        return self._client.request(path)
+
     def query(self, query_string: str) -> dict:
         if not self._proxy_influx_db:
             self.boot_data()
