@@ -27,7 +27,7 @@ class HttpClient:
             total=3,
             backoff_factor=0.5,
             status_forcelist=[429, 500, 502, 503, 504],
-            method_whitelist=["TRACE", "PUT", "DELETE", "OPTIONS", "HEAD", "GET", "POST"],
+            allowed_methods=["TRACE", "PUT", "DELETE", "OPTIONS", "HEAD", "GET", "POST"],
             raise_on_status=False,
         )))
 
@@ -36,9 +36,10 @@ class HttpClient:
                 body: Optional[dict] = None,
                 headers: Optional[dict] = None,
                 parameters: Optional[dict] = None,
-                return_json = True
+                return_json=True
                 ) -> Union[dict, requests.Response]:
         try:
+            self._log.debug(f"Making request {method} {url} {parameters if parameters else ''} with timeout {self.http_timeout}")
             r = self._session.request(method,
                                       url,
                                       json=body,
